This function can generate a set of optimal design parameters based on given distributions of the rank of optimization target (or budget).
gen.design.pars(
dist.mean,
dist.rank,
n.of.ants,
nl,
q = 1e-04,
n.of.archive = 100,
xi = 0.5
)Generated optimal design parameter value(s) (i.e., a matrix with n.of.ants rows and n.of.design.pars columns)
List of means - coordinates
Rank of the archived values of the objective function(s)
The number of artificial ants in the search.
Neighborhood of the search area
The locality of the search (0, 1)
The number of the solution archive.
The convergence pressure (0, Inf)
Socha, K., & Dorigo, M. (2008). Ant colony optimization for continuous domains. European Journal of Operational Research, 185(3), 1155-1173.
We thank Dr. Krzysztof Socha for providing us the original code (https://iridia.ulb.ac.be/supp/IridiaSupp2008-001/) for this function.